
## Eurojob 

library(foreign)
eurojob.file <- "c:/AMDSS/Rwork/code/chapter5/eurojob.sav"
# the data file path needs to be changed to the file's location on your computer

eurojob.data <- read.spss(eurojob.file, to.data.frame=TRUE)
head(eurojob.data)
eurojob.mat <- data.matrix(subset(eurojob.data, select=-COUNTRY))


eurojob.pca <- princomp(eurojob.mat, cor=TRUE)
class(eurojob.pca)
methods(class=princomp)
summary(eurojob.pca, loadings=TRUE)


plot(eurojob.pca)


plot(eurojob.pca$sdev^2, type="b", pch=16, xlab="Component number", ylab="Eigenvalue", main="Scree plot for European Employment data")


round(
      cbind("Variance"=eurojob.pca$sdev^2,
            "%"=100*eurojob.pca$sdev^2/sum(eurojob.pca$sdev^2),
            "Cumulative %"=100*cumsum(eurojob.pca$sdev^2)/sum(eurojob.pca$sdev^2)),
      d=2)


## a-star values
a.star <- eurojob.pca$loadings*rep(eurojob.pca$sdev, each=length(eurojob.pca$sdev))
print(round(a.star, d=2), cutoff=0)


plot(a.star[, 1], -1*a.star[, 2], axes=FALSE, xlim=c(-1, 1), ylim=c(-1, 1), xlab="", ylab="")
mtext(expression(a[i1]^"*"), 2, las=1)
mtext(expression(a[i2]^"*"), 3, las=1)
axis(1, at=c(-1, 1), pos=0)
axis(2, at=c(-1, 1), pos=0)
text(a.star[, 1], -1*a.star[, 2], labels=colnames(eurojob.mat), pos=3, cex=0.5)


## Component score coefficients (compare with Table 5.9 of the text)
comp.coef <- eurojob.pca$loadings/rep(eurojob.pca$sdev, each=length(eurojob.pca$sdev))
print(round(comp.coef, d=2), cutoff=0)


std.scores <- scale(eurojob.mat) %*% (comp.coef[, 1:2] %*% diag(c(1, -1)))
plot(std.scores[, 1], std.scores[, 2], xlab="", ylab="", las=1, xlim=c(-4, 2), ylim=c(-2, 3), cex.axis=0.75)
mtext(expression(tilde(y)[1]), side=1, line=2.1, las=1)
mtext(expression(tilde(y)[2]), side=2, line=2.1, las=1)
text(std.scores[, 1], std.scores[, 2], labels=eurojob.data$COUNTRY, pos=3, cex=0.5)


